@@ -5,11 +5,19 @@ Obsidian to Hugo CLI
 import argparse
 import os
 from .obsidian_to_hugo import ObsidianToHugo
+from obsidian_to_hugo import __version__
 
-__version__ = "0.2.0"
 
 parser = argparse.ArgumentParser()
 
+parser.add_argument(
+    "--version",
+    "-v",
+    action="version",
+    version=f"obsidian-to-hugo {__version__}",
+    help="Show the version and exit.",
+)
+
 parser.add_argument(
     "--hugo-content-dir",
     help="Directory of your Hugo content directory, the obsidian notes should be processed into.",
@@ -36,7 +44,7 @@ def main() -> None:
         obsidian_vault_dir=args.obsidian_vault_dir,
         hugo_content_dir=args.hugo_content_dir,
     )
-    obsidian_to_hugo.process()
+    obsidian_to_hugo.run()
 
 
 if __name__ == "__main__":
